@@ -13,7 +13,7 @@ use strict;
 use POE::Filter;
 
 use vars qw($VERSION @ISA);
-$VERSION = '1.363';
+$VERSION = '1.367';
 # NOTE - Should be #.### (three decimal places)
 @ISA = qw(POE::Filter);
 
@@ -33,7 +33,7 @@ sub FIRST_UNUSED  () { 9 }
 sub ST_HEADERS    () { 0x01 } # waiting for complete header block
 sub ST_CONTENT    () { 0x02 } # waiting for complete body
 
-use Carp qw(croak);
+use Carp qw(croak cluck carp);
 use HTTP::Status qw( status_message RC_BAD_REQUEST RC_OK RC_LENGTH_REQUIRED 
                                     RC_REQUEST_ENTITY_TOO_LARGE );
 use HTTP::Request ();
@@ -70,9 +70,9 @@ BEGIN {
         if( $@ ) {
             DEBUG and warn "We don't have Email::MIME::RFC2047::Encoder";
             *encode_value = sub {
-              Carp::cluck(
+              cluck(
                 "Downgrading wide characters in HTTP header. " .
-                "Consier installing Email::MIME::RFC2047::Encoder"
+                "Consider installing Email::MIME::RFC2047::Encoder"
               );
               $downgrade->( @_ );
             };
@@ -652,7 +652,7 @@ block of content.  The HTTP::Request object's content will return empty.
 The blocks of content will be parts of the request's body, up to
 Content-Length in size.  You distinguish between request objects and content
 blocks using C<Scalar::Util/bless> (See L</Streaming request> below).  This
-option superceeds L</MaxContent>.
+option supersedes L</MaxContent>.
 
 =head1 CAVEATS
 
@@ -696,7 +696,7 @@ request with a clean connection and filter.
 
 Normally POE::Filter::HTTPD reads the entire request content into memory
 before returning the HTTP::Request to your code.  In streaming mode, it will
-return the content seprately, as unblessed scalars.  The content may be
+return the content separately, as unblessed scalars.  The content may be
 split up into blocks of varying sizes, depending on OS and transport
 constraints.  Your code can distinguish the request object from the content
 blocks using L<Scalar::Util/blessed>.
